@@ -27,10 +27,16 @@ class KozaiArtifactRepository(AzureBlobArtifactRepository):
                 f"Unknown kozai artifact repository uri: {artifact_uri}"
             )
 
-        self.client = ContainerClient.from_container_url(
+        container_client = ContainerClient.from_container_url(
             container_url=os.environ["MLFLOW_ARTIFACTS_AZURE_STORAGE_SAS_URI"],
         )
 
+        class ServiceClientMock:
+            def get_container_client(container):
+                return container_client
+
+        self.client = ServiceClientMock()
+
     @staticmethod
     def parse_wasbs_uri(artifact_uri: str):
         """
